@@ -1325,6 +1325,7 @@ class VariableOsLocationFormat(LocationHelper, Variable):
         availFS = set(self.Select('os_format_type',
                                   where='os_format_use',
                                   eq='yes'))
+        allAvailFS = self.Get('os_format_type')
 
         default_format = None
         if self.Get('os_root_type_ext') in RootType.HDD:
@@ -1344,8 +1345,8 @@ class VariableOsLocationFormat(LocationHelper, Variable):
                     return "swap"
                 elif mount.startswith('/boot/efi'):
                     return "vfat"
-                if dev in diskFormat and diskFormat[dev] in availFS:
-                    if mount.count('/') == 1:
+                if dev in diskFormat and diskFormat[dev] in allAvailFS:
+                    if mount.count('/') == 1 or mount == "/var/calculate":
                         if FileSystemManager.checkFSForTypeMount(
                                 diskFormat[dev],
                                 osInstallRootType, mount):
